@@ -2,17 +2,21 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from .party import *
-from .sale import *
-from .product import *
+from . import party
+from . import sale
+from . import product
 from . import configuration
 
 
 def register():
     Pool.register(
-        Party,
-        Sale,
-        SaleLine,
-        Product,
+        party.Party,
+        party.PartySalePriceList,
+        sale.Sale,
+        sale.Line,
+        product.Product,
+        product.PriceList,
+        product.SaleContext,
         configuration.Configuration,
+        configuration.ConfigurationSalePriceList,
         module='sale_price_list', type_='model')
