@@ -8,11 +8,8 @@ from trytond.tools.multivalue import migrate_property
 from trytond.modules.company.model import (
     CompanyMultiValueMixin, CompanyValueMixin)
 
-__all__ = ['Party', 'PartySalePriceList']
 
-
-class Party(CompanyMultiValueMixin):
-    __metaclass__ = PoolMeta
+class Party(CompanyMultiValueMixin, metaclass=PoolMeta):
     __name__ = 'party.party'
     sale_price_list = fields.MultiValue(fields.Many2One(
             'product.price_list', "Sale Price List",
@@ -39,7 +36,11 @@ class PartySalePriceList(ModelSQL, CompanyValueMixin):
     "Party Sale Price List"
     __name__ = 'party.party.sale_price_list'
     party = fields.Many2One(
-        'party.party', "Party", ondelete='CASCADE', select=True)
+        'party.party', "Party", ondelete='CASCADE', select=True,
+        context={
+            'company': Eval('company', -1),
+            },
+        depends=['company'])
     sale_price_list = fields.Many2One(
         'product.price_list', "Sale Price List",
         domain=[
@@ -49,8 +50,7 @@ class PartySalePriceList(ModelSQL, CompanyValueMixin):
 
     @classmethod
     def __register__(cls, module_name):
-        TableHandler = backend.get('TableHandler')
-        exist = TableHandler.table_exist(cls._table)
+        exist = backend.TableHandler.table_exist(cls._table)
 
         super(PartySalePriceList, cls).__register__(module_name)
 
